@@ -34,13 +34,18 @@ sub get_all_service_units
 # mandatory attributes
 
 my $mandatory_attributes =
-    [ 'siam.device.inventory_id' ];
+    [ 'siam.device.inventory_id',
+      'siam.device.name'];
 
 sub _mandatory_attributes
 {
     return $mandatory_attributes;
 }
 
+sub _manifest_attributes
+{
+    return $mandatory_attributes;
+}
 
 1;
 
