@@ -42,6 +42,16 @@ sub _mandatory_attributes
     return $mandatory_attributes;
 }
 
+sub _manifest_attributes
+{
+    my $ret = [];
+    push(@{$ret}, @{$mandatory_attributes},
+         @{ SIAM::ServiceUnit->_manifest_attributes() });
+
+    return $ret;
+
+}
+
 
 1;
 
